@@ -6,10 +6,10 @@ from .array_utils import *
 from .smooth_utils import *
 from .math_utils import *
 from .physics_utils import *
-#from .cosmo_utils import *
+from .cosmo_utils import *
 from .fitting_utils import *
-#from .snapshot_utils import *
-#from .plot_utils import * ## need to answer test, can at least smoke test
+from .snapshot_utils import *
+from .plot_utils import * ## need to answer test, can at least smoke test
 from .color_utils import * ## does not make sense to unit test
 
 ## define some constants
